# TCompress

TCompress is a Python package for various data processing operations, including image manipulation, file management, and random value generation.

## Table of Contents

- [Installation](#installation)
- [Usage](#usage)
- [Documentation](#documentation)
- [Examples](#examples)
- [Contributing](#contributing)
- [License](#license)

## Installation

You can install TCompress using pip:

```bash
$ pip install tcompress
```

## Usage

To use TCompress in your Python project, import the relevant module and call its functions. Here are the available modules and their respective functions:

## Image Module (image.py)

The Image module provides functions for working with images.

Functions:

- `add_padding``: Adds padding to an image.
- `round_corners``: Rounds the corners of an image.
- `turn_to_square``: Converts an image into a square by adding background color.

```python
import tcompress.image as image

image.add_padding(image_path, padding_value, color)
```

## File Module (manage.py)

The File module provides functions for file management operations.

Functions:

- `read_lines`: Reads lines from a file.
- `count_lines`: Counts the number of lines in a file.
- `count_folders`: Counts the number of folders in a directory.
- `count_files`: Counts the number of files in a directory.
- `get_file_info`: Gets information about a file.
- `get_file_name`: Gets the name of a file.
- `get_file_extension`: Gets the extension of a file.
- `get_file_location`: Gets the location of a file.
- `is_file`: Checks if a path string corresponds

```python
import tcompress.manage as file

lines = file.read_lines(file_path)
```

## Random Module (random.py)

The File module provides functions for file management operations.

Functions:

- `random_integer`: Generates a random integer with n digits.
- `random_string`: Generates a random string with n uppercase letters.
- `random_serial`: Generates a random serial code with n alphanumeric characters.

```python
import tcompress.random as random

random_integer = random.random_integer(n)
```

## Time Module (time.py)

The Time module provides functions for working with dates and time.

Variables:

- `months`: A list of month names.

Functions:

- `get_date`: Returns the current date in the format "MM/DD/YYYY".
- `get_month`: Returns the current month index and name.
- `get_year`: Returns the current year as an integer.

```python
import tcompress.time as time

current_date = time.get_date()
```


## License

`tcompress` was created by Talal El Zeini. It is licensed under the terms
of the MIT license.
